@@ -34,6 +34,7 @@ import math
 import tkinter as tk
 import operator
 
+from pyworkflow import Config
 from pyworkflow.gui import gui, getDefaultFont, cfgFontSize
 from pyworkflow.gui.widgets import Scrollable
 
@@ -51,7 +52,7 @@ class Canvas(tk.Canvas, Scrollable):
     _images = {}
 
     def __init__(self, parent, tooltipCallback=None, tooltipDelay=1500, **kwargs):
-        defaults = {'bg': 'white'}
+        defaults = {'bg': Config.SCIPION_BG_COLOR}
         defaults.update(kwargs)
         Scrollable.__init__(self, parent, tk.Canvas, **defaults)
 
@@ -220,9 +221,19 @@ class Canvas(tk.Canvas, Scrollable):
                     self._menu.add_separator()
                 else:
                     img = ''
-                    if len(a) > 2:  # image for the action
+                    label= a[0]
+                    size = len(a)
+
+                    if size > 2:  # image for the action
                         img = self.getImage(a[2])
-                    self._menu.add_command(label=a[0], command=a[1],
+
+                        # Shortcuts
+                        if size > 3:
+                            shortCut = a[3]
+                            if shortCut:
+                                label= "%s (%s)" % (label, shortCut)
+
+                    self._menu.add_command(label=label, command=a[1],
                                            image=img, compound=tk.LEFT,
                                            font=gui.getDefaultFont())
             self._menu.post(e.x_root, e.y_root)
