@@ -31,7 +31,7 @@ some code was taken from tkSimpleDialog
 import tkinter as tk
 import traceback
 from tkcolorpicker import askcolor as _askColor
-
+from pyworkflow import Config
 from pyworkflow.exceptions import PyworkflowException
 from pyworkflow.utils import Message, Icon, Color
 from . import gui, Window, widgets, configureWeigths, LIST_TREEVIEW, defineStyle
@@ -71,6 +71,8 @@ class Dialog(tk.Toplevel):
             parent = tk.Tk()
             parent.withdraw()
             gui.setCommonFonts()
+            # invoke the button on the return key
+            parent.bind_class("Button", "<Key-Return>", lambda event: event.widget.invoke())
 
         tk.Toplevel.__init__(self, parent)
 
@@ -97,6 +99,14 @@ class Dialog(tk.Toplevel):
         bodyFrame.grid(row=0, column=0, sticky='news',
                        padx=5, pady=5)
 
+        # Frame for the info/message label
+        infoFrame = tk.Frame(self)
+        infoFrame.grid(row=1, column=0, sticky='sew',
+                      padx=5, pady=(0, 5))
+        self.floatingMessage = tk.Label(infoFrame, text="", fg=Config.SCIPION_MAIN_COLOR)
+        self.floatingMessage.grid(row=0, column=0, sticky='news')
+
+        # Create buttons
         self.icons = kwargs.get('icons',
                                 {RESULT_YES: Icon.BUTTON_SELECT,
                                  RESULT_NO: Icon.BUTTON_CLOSE,
@@ -106,10 +116,11 @@ class Dialog(tk.Toplevel):
         self.buttons = kwargs.get('buttons', [('OK', RESULT_YES),
                                               ('Cancel', RESULT_CANCEL)])
         self.defaultButton = kwargs.get('default', 'OK')
+
+        # Frame for buttons
         btnFrame = tk.Frame(self)
-        # Create buttons 
         self.buttonbox(btnFrame)
-        btnFrame.grid(row=1, column=0, sticky='sew',
+        btnFrame.grid(row=2, column=0, sticky='sew',
                       padx=5, pady=(0, 5))
 
         gui.configureWeigths(self)
@@ -239,6 +250,10 @@ class Dialog(tk.Toplevel):
     def resultCancel(self):
         return self.result == RESULT_CANCEL
 
+    def info(self, message):
+        """ Shows a info message for long running processes to inform the user GUI is not frozen"""
+        self.floatingMessage.config(text=message)
+
 
 def fillMessageText(text, message):
     # Insert lines of text
@@ -260,8 +275,8 @@ def fillMessageText(text, message):
 
 
 def createMessageBody(bodyFrame, message, image,
-                      frameBg='white',
-                      textBg='white',
+                      frameBg=Config.SCIPION_BG_COLOR,
+                      textBg=Config.SCIPION_BG_COLOR,
                       textPad=5):
     """ Create a Text containing the message.
     Params:
@@ -310,7 +325,7 @@ class ExceptionDialog(MessageDialog):
         super().body(bodyFrame)
 
         def addTraceback(event):
-            detailsText = TaggedText(bodyFrame, bg='white', bd=0, highlightthickness=0)
+            detailsText = TaggedText(bodyFrame, bg=Config.SCIPION_BG_COLOR, bd=0, highlightthickness=0)
             traceStr = traceback.format_exc()
             fillMessageText(detailsText, traceStr)
             detailsText.frame.grid(row=row+1, column=0, columnspan=2, sticky='news', padx=5, pady=5)
@@ -321,12 +336,12 @@ class ExceptionDialog(MessageDialog):
 
             if isinstance(self._exception, PyworkflowException):
                 helpUrl = self._exception.getUrl()
-                labelUrl = TaggedText(bodyFrame, bg='white', bd=0, highlightthickness=0)
+                labelUrl = TaggedText(bodyFrame, bg=Config.SCIPION_BG_COLOR, bd=0, highlightthickness=0)
                 fillMessageText(labelUrl,"Please go here for more details: %s" % helpUrl)
                 labelUrl.grid(row=row, column=0, columnspan=2, sticky='news')
                 row += 1
 
-            label = tk.Label(bodyFrame, text="Show details...", bg='white', bd=0)
+            label = tk.Label(bodyFrame, text="Show details...", bg=Config.SCIPION_BG_COLOR, bd=0)
             label.grid(row=row, column=0, columnspan=2, sticky='news')
             label.bind("<Button-1>", addTraceback)
 
@@ -393,15 +408,15 @@ class EntryDialog(Dialog):
         Dialog.__init__(self, parent, title)
 
     def body(self, bodyFrame):
-        bodyFrame.config(bg='white')
-        frame = tk.Frame(bodyFrame, bg='white')
+        bodyFrame.config(bg=Config.SCIPION_BG_COLOR)
+        frame = tk.Frame(bodyFrame, bg=Config.SCIPION_BG_COLOR)
         frame.grid(row=0, column=0, padx=20, pady=20)
         row = 0
         if self.headerLabel:
-            label = tk.Label(bodyFrame, text=self.headerLabel, bg='white', bd=0)
+            label = tk.Label(bodyFrame, text=self.headerLabel, bg=Config.SCIPION_BG_COLOR, bd=0)
             label.grid(row=row, column=0, columnspan=2, sticky='nw', padx=(15, 10), pady=15)
             row += 1
-        label = tk.Label(bodyFrame, text=self.entryLabel, bg='white', bd=0)
+        label = tk.Label(bodyFrame, text=self.entryLabel, bg=Config.SCIPION_BG_COLOR, bd=0)
         label.grid(row=row, column=0, sticky='nw', padx=(15, 10), pady=15)
         self.entry = tk.Entry(bodyFrame, bg=gui.cfgEntryBgColor,
                               width=self.entryWidth, textvariable=self.tkvalue)
@@ -438,12 +453,12 @@ class EditObjectDialog(Dialog):
         Dialog.__init__(self, parent, title, **kwargs)
 
     def body(self, bodyFrame):
-        bodyFrame.config(bg='white')
-        frame = tk.Frame(bodyFrame, bg='white')
+        bodyFrame.config(bg=Config.SCIPION_BG_COLOR)
+        frame = tk.Frame(bodyFrame, bg=Config.SCIPION_BG_COLOR)
         frame.grid(row=0, column=0, padx=20, pady=20)
 
         # Label
-        label_text = tk.Label(bodyFrame, text=self.labelText, bg='white', bd=0)
+        label_text = tk.Label(bodyFrame, text=self.labelText, bg=Config.SCIPION_BG_COLOR, bd=0)
         label_text.grid(row=0, column=0, sticky='nw', padx=(15, 10), pady=15)
         # Label box
         var = tk.StringVar()
@@ -452,7 +467,7 @@ class EditObjectDialog(Dialog):
         self.textLabel.grid(row=0, column=1, sticky='news', padx=5, pady=5)
 
         # Comment
-        label_comment = tk.Label(bodyFrame, text=self.commentLabel, bg='white', bd=0)
+        label_comment = tk.Label(bodyFrame, text=self.commentLabel, bg=Config.SCIPION_BG_COLOR, bd=0)
         label_comment.grid(row=1, column=0, sticky='nw', padx=(15, 10), pady=15)
         # Comment box
         self.textComment = Text(bodyFrame, height=self.commentHeight,
@@ -543,20 +558,22 @@ class ListDialog(Dialog):
 
     def __init__(self, parent, title, provider, message=None, **kwargs):
         """ From kwargs:
-                message: message tooltip to show when browsing.
-                selected: the item that should be selected.
-                validateSelectionCallback:
-                    a callback function to validate selected items.
-                allowSelect: if set to False, the 'Select' button will not
-                    be shown.
-                allowsEmptySelection: if set to True, it will not validate
-                    that at least one element was selected.
+
+        :param message: message tooltip to show when browsing.
+        :param validateSelectionCallback: a callback function to validate selected items.
+        :param previewCallback: method to be called on item click to fill the callback frame.
+        :param selectmode: 'extended' by default. Selection mode of the tk.Tree
+        :param selectOnDoubleClick: (False). If True, double click will trigger "Select" button click
+        :param allowsEmptySelection: (False). Allows empty selection
+        :param allowSelect: if set to False, the 'Select' button will not be shown.
+        :param allowsEmptySelection: if set to True, it will not validate that at least one element was selected.
         """
         self.values = []
         self.provider = provider
         self.message = message
-        self.validateSelectionCallback = kwargs.get('validateSelectionCallback',
-                                                    None)
+        self.validateSelectionCallback = kwargs.get('validateSelectionCallback', None)
+        self.previewCallBack = kwargs.get('previewCallback', None)
+
         self._selectmode = kwargs.get('selectmode', 'extended')
         self._selectOnDoubleClick = kwargs.get('selectOnDoubleClick', False)
         self._allowsEmptySelection = kwargs.get('allowsEmptySelection', False)
@@ -580,6 +597,9 @@ class ListDialog(Dialog):
         gui.configureWeigths(dialogFrame, row=1)
         self._createFilterBox(dialogFrame)
         self._createTree(dialogFrame)
+        if self.previewCallBack:
+            self._createPreviewPanel(dialogFrame)
+
         if self.message:
             label = tk.Label(bodyFrame, text=self.message, compound=tk.LEFT,
                              image=self.getImage(Icon.LIGHTBULB))
@@ -590,8 +610,19 @@ class ListDialog(Dialog):
         self.tree = BoundTree(parent, self.provider, selectmode=self._selectmode, style=LIST_TREEVIEW)
         if self._selectOnDoubleClick:
             self.tree.itemDoubleClick = lambda obj: self._handleResult(RESULT_YES)
+
+        if self.previewCallBack:
+            self.tree.itemClick = self._itemClick
+
         self.tree.grid(row=1, column=0)
 
+    def _itemClick(self, obj):
+        self.previewCallBack(obj, self.previewFrame)
+
+    def _createPreviewPanel(self, parent):
+        self.previewFrame = tk.Frame(parent)
+        self.previewFrame.grid(row=1,column=1)
+
     def _createFilterBox(self, content):
         """ Create the Frame with Filter widgets """
 
@@ -629,7 +660,7 @@ class ListDialog(Dialog):
         label = tk.Label(self.searchBoxframe, text="Filter")
         label.grid(row=0, column=0, sticky='nw')
         self._searchVar = tk.StringVar(value='')
-        self.entry = tk.Entry(self.searchBoxframe, bg='white',
+        self.entry = tk.Entry(self.searchBoxframe, bg=Config.SCIPION_BG_COLOR,
                               textvariable=self._searchVar, width=40,
                               font=gui.getDefaultFont())
 
@@ -694,12 +725,12 @@ class ToolbarListDialog(ListDialog):
         ListDialog.__init__(self, parent, title, provider, message, **kwargs)
 
     def body(self, bodyFrame):
-        bodyFrame.config(bg='white')
+        bodyFrame.config(bg=Config.SCIPION_BG_COLOR)
         gui.configureWeigths(bodyFrame, 1, 0)
 
         # Add an extra frame to insert the Toolbar
         # and another one for the ListDialog's body
-        self.toolbarFrame = tk.Frame(bodyFrame, bg='white')
+        self.toolbarFrame = tk.Frame(bodyFrame, bg=Config.SCIPION_BG_COLOR)
         self.toolbarFrame.grid(row=0, column=0, sticky='new')
         if self.toolbarButtons:
             for i, b in enumerate(self.toolbarButtons):
@@ -714,7 +745,7 @@ class ToolbarListDialog(ListDialog):
     def _addButton(self, button, col):
         btn = tk.Label(self.toolbarFrame, text=button.text,
                        image=self.getImage(button.icon),
-                       compound=tk.LEFT, cursor='hand2', bg='white')
+                       compound=tk.LEFT, cursor='hand2', bg=Config.SCIPION_BG_COLOR)
         btn.grid(row=0, column=col, sticky='nw', padx=(5, 0), pady=(5, 0))
         btn.bind('<Button-1>', button.command)
 
@@ -748,13 +779,21 @@ class FlashMessage:
 
 
 class FloatingMessage:
-    def __init__(self, master, msg, xPos=750, yPos=80, textWidth=280,
-                 font='Helvetica', size=12, bd=1, bg='#6E6E6E', fg='white'):
+    def __init__(self, master, msg, xPos=None, yPos=None, textWidth=280,
+                 font='Helvetica', size=12, bd=1, bg=Config.SCIPION_MAIN_COLOR, fg='white'):
+
+        if xPos is None:
+            xPos = (master.winfo_width()-textWidth)/2
+            yPos = master.winfo_height()/2
+
         self.floatingMessage = tk.Label(master, text="   %s   " % msg,
                                         bd=bd, bg=bg, fg=fg)
         self.floatingMessage.place(x=xPos, y=yPos, width=textWidth)
         self.floatingMessage.config(font=(font, size))
 
+    def setMessage(self, msg):
+        self.floatingMessage.config(text=msg)
+
     def show(self):
         self.floatingMessage.update_idletasks()
 
@@ -777,11 +816,11 @@ class FileBrowseDialog(Dialog):
                         buttons=[('Select', RESULT_YES), ('Cancel', RESULT_CANCEL)])
 
     def body(self, bodyFrame):
-        bodyFrame.config(bg='white')
+        bodyFrame.config(bg=Config.SCIPION_BG_COLOR)
         gui.configureWeigths(bodyFrame)
         self._createTree(bodyFrame)
         if self.message:
-            label = tk.Label(bodyFrame, text=self.message, bg='white',
+            label = tk.Label(bodyFrame, text=self.message, bg=Config.SCIPION_BG_COLOR,
                              image=self.getImage(Icon.LIGHTBULB), compound=tk.LEFT)
             label.grid(row=1, column=0, sticky='nw', padx=5, pady=5)
         self.initial_focus = self.tree
@@ -840,7 +879,7 @@ class SearchBaseWindow(Window):
         self.onClick = self._click if onClick is None else onClick
         self.onDoubleClick = self._double_click if onDoubleClick is None else onDoubleClick
 
-        content = tk.Frame(self.root, bg='white')
+        content = tk.Frame(self.root, bg=Config.SCIPION_BG_COLOR)
         self._createContent(content)
         content.grid(row=0, column=0, sticky='news')
         content.columnconfigure(0, weight=1)
@@ -855,9 +894,9 @@ class SearchBaseWindow(Window):
 
     def _createSearchBox(self, content):
         """ Create the Frame with Search widgets """
-        frame = tk.Frame(content, bg='white')
+        frame = tk.Frame(content, bg=Config.SCIPION_BG_COLOR)
 
-        label = tk.Label(frame, text="Search", bg='white')
+        label = tk.Label(frame, text="Search", bg=Config.SCIPION_BG_COLOR)
         label.grid(row=0, column=0, sticky='nw')
         self._searchVar = tk.StringVar()
         entry = tk.Entry(frame, bg='white', textvariable=self._searchVar, font=gui.getDefaultFont())
@@ -873,7 +912,7 @@ class SearchBaseWindow(Window):
         frame.grid(row=0, column=0, sticky='new', padx=5, pady=(10, 5))
 
     def _createResultsBox(self, content):
-        frame = tk.Frame(content, bg=Color.LIGHT_GREY_COLOR, padx=5, pady=5)
+        frame = tk.Frame(content, bg=Color.ALT_COLOR, padx=5, pady=5)
         configureWeigths(frame)
         self._resultsTree = self._createResultsTree(frame,
                                                     show=None,
