@@ -28,11 +28,14 @@ import queue
 from functools import partial
 from tkinter.ttk import Style
 
-from pyworkflow.object import Object
 import pyworkflow as pw
-from pyworkflow.utils import Message, Color, Icon
-
+from pyworkflow.object import Object
+from pyworkflow.utils import Message, Icon
+from PIL import Image, ImageTk
 from .widgets import Button
+import numpy as np
+
+DEFAULT_WINDOW_CLASS = "Scipion Framework"
 
 # --------------- GUI CONFIGURATION parameters -----------------------
 # TODO: read font size and name from config file
@@ -44,29 +47,29 @@ cfgFontName = pw.Config.SCIPION_FONT_NAME
 cfgFontSize = pw.Config.SCIPION_FONT_SIZE
 cfgFontBigSize = cfgFontSize + 8
 # TextColor
-cfgCitationTextColor = "dark olive green"
-cfgLabelTextColor = "black"
-cfgSectionTextColor = "blue4"
+# cfgCitationTextColor = "dark olive green"
+# cfgLabelTextColor = "black"
+# cfgSectionTextColor = "blue4"
 # Background Color
-cfgBgColor = "light grey"
-cfgLabelBgColor = "white"
-cfgHighlightBgColor = cfgBgColor
-cfgButtonFgColor = "white"
-cfgButtonActiveFgColor = "white"
-cfgButtonBgColor = Color.RED_COLOR
-cfgButtonActiveBgColor = "#A60C0C"
+# cfgBgColor = "light grey"
+# cfgLabelBgColor = "white"
+# cfgHighlightBgColor = cfgBgColor
+cfgButtonFgColor = pw.Config.SCIPION_BG_COLOR
+cfgButtonActiveFgColor = pw.Config.SCIPION_BG_COLOR
+cfgButtonBgColor = pw.Config.SCIPION_MAIN_COLOR
+cfgButtonActiveBgColor = pw.Config.getActiveColor()
 cfgEntryBgColor = "lemon chiffon"
-cfgExpertLabelBgColor = "light salmon"
-cfgSectionBgColor = cfgButtonBgColor
+# cfgExpertLabelBgColor = "light salmon"
+# cfgSectionBgColor = cfgButtonBgColor
 # Color
-cfgListSelectColor = "DeepSkyBlue4"
-cfgBooleanSelectColor = "white"
-cfgButtonSelectColor = "DeepSkyBlue2"
+# cfgListSelectColor = "DeepSkyBlue4"
+# cfgBooleanSelectColor = "white"
+# cfgButtonSelectColor = "DeepSkyBlue2"
 # Dimensions limits
-cfgMaxHeight = 650
+# cfgMaxHeight = 650
 cfgMaxWidth = 800
-cfgMaxFontSize = 14
-cfgMinFontSize = 6
+# cfgMaxFontSize = 14
+# cfgMinFontSize = 6
 cfgWrapLenght = cfgMaxWidth - 50
 
 # Style of treeviews where row height is variable based on the font size
@@ -204,8 +207,9 @@ def getImage(imageName, imgDict=None, tkImage=True, percent=100,
         imagePath = imageName
     image = None
     if imagePath:
-        from PIL import Image
         image = Image.open(imagePath)
+        # For a future dark mode we might need to invert the image but it requires some extra work to make it look nice:
+        # image = invertImage(image)
         w, h = image.size
         newSize = None
         if percent != 100:  # Display image with other dimensions
@@ -216,12 +220,24 @@ def getImage(imageName, imgDict=None, tkImage=True, percent=100,
         if newSize:
             image.thumbnail(newSize, Image.ANTIALIAS)
         if tkImage:
-            from PIL import ImageTk
             image = ImageTk.PhotoImage(image)
+
         image_cache[imageName] = image
     return image
 
+def invertImage(img):
+    # Creating a numpy array out of the image object
+    img_arry = np.array(img)
 
+    # Maximum intensity value of the color mode
+    I_max = 255
+
+    # Subtracting 255 (max value possible in a given image
+    # channel) from each pixel values and storing the result
+    img_arry = I_max - img_arry
+
+    # Creating an image object from the resultant numpy array
+    return Image.fromarray(img_arry)
 # ---------------- Windows geometry utilities -----------------------
 def getGeometry(win):
     """ Return the geometry information of the windows
@@ -236,7 +252,7 @@ def centerWindows(root, dim=None, refWindows=None):
     or in the middle of other windows(refWindows param)"""
     root.update_idletasks()
     if dim is None:
-        gw, gh, gx, gy = getGeometry(root)
+        gw, gh, _, _ = getGeometry(root)
     else:
         gw, gh = dim
     if refWindows:
@@ -271,13 +287,15 @@ def defineStyle():
     defaultFont = getDefaultFont()
     rowheight = defaultFont.metrics()['linespace']
 
-    style.configure(LIST_TREEVIEW, rowheight=rowheight)
+    style.configure(LIST_TREEVIEW, rowheight=rowheight,
+                    background=pw.Config.SCIPION_BG_COLOR,
+                    fieldbackground=pw.Config.SCIPION_BG_COLOR)
     style.configure(LIST_TREEVIEW+".Heading", font=(defaultFont["family"],defaultFont["size"]))
 
 
 class Window:
     """Class to manage a Tk windows.
-    It will encapsulates some basic creation and 
+    It will encapsulate some basic creation and
     setup functions. """
     # To allow plugins to add their own menus
     _pluginMenus = dict()
@@ -305,10 +323,17 @@ class Window:
             # Solution proposed is to generate the root as an invisible window if it doesn't exist previously, and make
             # he first window generated a tk.Toplevel. After that, all steps executed later will go through the else
             # statement, being that way each new tk.Toplevel() correctly referenced.
-            tk.Tk().withdraw()  # Main window, invisible
-            self.root = tk.Toplevel()  # Toplevel of main window
+            root = tk.Tk()
+            root.withdraw()  # Main window, invisible
+            # invoke the button on the return key
+            root.bind_class("Button", "<Key-Return>", lambda event: event.widget.invoke())
+
+            self._class = kwargs.get("_class", DEFAULT_WINDOW_CLASS)
+            self.root = tk.Toplevel(class_=self._class)  # Toplevel of main window
         else:
-            self.root = tk.Toplevel(masterWindow.root)
+            class_ = masterWindow._class if hasattr(masterWindow, "_class") else DEFAULT_WINDOW_CLASS
+            self.root = tk.Toplevel(masterWindow.root, class_=class_)
+            self.root.group(masterWindow.root)
             self._images = masterWindow._images
 
         self.root.withdraw()
