@@ -31,6 +31,7 @@ import tkinter as tk
 import tkinter.ttk as ttk
 import tkinter.font as tkFont
 
+from pyworkflow import Config
 import pyworkflow.utils as pwutils
 import pyworkflow.protocol as pwprot
 import pyworkflow.viewer as pwviewer
@@ -122,16 +123,16 @@ class ProjectDataView(tk.Frame):
             Left: containing the Protocol classes tree
             Right: containing the Data list
         """
-        p = tk.PanedWindow(self, orient=tk.HORIZONTAL, bg='white')
+        p = tk.PanedWindow(self, orient=tk.HORIZONTAL, bg=Config.SCIPION_BG_COLOR)
         
         # Left pane, contains Data tree
-        leftFrame = tk.Frame(p, bg='white')
+        leftFrame = tk.Frame(p, bg=Config.SCIPION_BG_COLOR)
         bgColor = '#eaebec'
         self._createDataTree(leftFrame, bgColor)
         gui.configureWeigths(leftFrame)
         
         # Right pane
-        rightFrame = tk.Frame(p, bg='white')
+        rightFrame = tk.Frame(p, bg=Config.SCIPION_BG_COLOR)
         rightFrame.columnconfigure(0, weight=1)
         rightFrame.rowconfigure(1, weight=1)
         # rightFrame.rowconfigure(0, minsize=label.winfo_reqheight())
@@ -151,7 +152,7 @@ class ProjectDataView(tk.Frame):
         """
         defaultFont = gui.getDefaultFont()
         self.style.configure("W.Treeview",
-                             background=pwutils.Color.LIGHT_GREY_COLOR,
+                             background=pwutils.Color.ALT_COLOR,
                              borderwidth=0,
                              rowheight=defaultFont.metrics()['linespace'])
         self.dataTree = Tree(parent, show='tree', style='W.Treeview')
@@ -215,31 +216,31 @@ class ProjectDataView(tk.Frame):
         # Selected run info (at Bottom)
         """
         # Create the Action Buttons TOOLBAR
-        toolbar = tk.Frame(parent, bg='white')
+        toolbar = tk.Frame(parent, bg=Config.SCIPION_BG_COLOR)
         toolbar.grid(row=0, column=0, sticky='news')
         gui.configureWeigths(toolbar)
         # toolbar.columnconfigure(0, weight=1)
         toolbar.columnconfigure(1, weight=1)
         
-        self.runsToolbar = tk.Frame(toolbar, bg='white')
+        self.runsToolbar = tk.Frame(toolbar, bg=Config.SCIPION_BG_COLOR)
         self.runsToolbar.grid(row=0, column=0, sticky='sw')
         # On the left of the toolbar will be other
         # actions that can be applied to all runs (refresh, graph view...)
-        self.allToolbar = tk.Frame(toolbar, bg='white')
+        self.allToolbar = tk.Frame(toolbar, bg=Config.SCIPION_BG_COLOR)
         self.allToolbar.grid(row=0, column=10, sticky='se')
         # self.createActionToolbar()
 
         # Create the Run History tree
         v = ttk.PanedWindow(parent, orient=tk.VERTICAL)
         # runsFrame = ttk.Labelframe(v, text=' History ', width=500, height=500)
-        runsFrame = tk.Frame(v, bg='white')
+        runsFrame = tk.Frame(v, bg=Config.SCIPION_BG_COLOR)
         self._createDataGraph(runsFrame)
         gui.configureWeigths(runsFrame)
         
         # Create the Selected Run Info
         infoFrame = tk.Frame(v)
         gui.configureWeigths(infoFrame)
-        self._infoText = TaggedText(infoFrame, bg='white',
+        self._infoText = TaggedText(infoFrame, bg=Config.SCIPION_BG_COLOR,
                                     handlers={'sci-open': self._openProtocolFormFromId})
         self._infoText.grid(row=0, column=0, sticky='news')
         
