@@ -27,6 +27,7 @@
 # *
 # **************************************************************************
 import logging
+import sys
 
 from .protocol import Protocol
 from .viewer import Viewer
@@ -84,6 +85,8 @@ class Domain:
 
             # Define variables
             m.Plugin._defineVariables()
+            m._pluginInstance = m.Plugin()
+
             m.Domain = cls  # Register the domain class for this module
             # TODO avoid loading bibtex here and make a lazy load like the rest.
             # Load bibtex
@@ -186,7 +189,7 @@ class Domain:
 
     @classmethod
     def __getSubclasses(cls, submoduleName, BaseClass,
-                        updateBaseClasses=False):
+                        updateBaseClasses=False, setPackage=False):
         """ Load all detected subclasses of a given BaseClass.
         Params:
             updateBaseClasses: if True, it will try to load classes from the
@@ -203,7 +206,7 @@ class Domain:
                         if inspect.isclass(attr) and issubclass(attr, BaseClass):
                             cls._baseClasses[name] = attr
 
-            for pluginName, plugin in cls.getPlugins().items():
+            for pluginName, module in cls.getPlugins().items():
                 sub = cls.__getSubmodule(pluginName, submoduleName)
                 if sub is not None:
                     for name in cls.getModuleClasses(sub):
@@ -222,7 +225,12 @@ class Domain:
                                        pluginCollision))
                             else:
                                 # Set this special property used by Scipion
-                                attr._package = plugin
+                                # Protocols need the package to be set
+                                if setPackage:
+
+                                    attr._plugin = getattr(module, "_pluginInstance", None)
+                                    attr._package = module
+
                                 subclasses[name] = attr
             subclasses.update(
                 pwutils.getSubclasses(BaseClass, cls._baseClasses))
@@ -246,7 +254,7 @@ class Domain:
     @classmethod
     def getProtocols(cls):
         """ Return all Protocol subclasses from all plugins for this domain."""
-        return cls.__getSubclasses('protocols', cls._protocolClass)
+        return cls.__getSubclasses('protocols', cls._protocolClass, setPackage=True)
 
     @classmethod
     def getObjects(cls):
@@ -262,7 +270,7 @@ class Domain:
     def getViewers(cls):
         """ Return all Viewer subclasses from all plugins for this domain."""
         return cls.__getSubclasses('viewers', cls._viewerClass,
-                                   updateBaseClasses=True)
+                                   updateBaseClasses=True, setPackage=True)
 
     @classmethod
     def getWizards(cls):
@@ -396,20 +404,28 @@ class Domain:
             preferedFlag = 0
 
             for viewer in cls.getViewers().values():
+                viewerAdded=False
                 if environment in viewer._environments:
                     for t in viewer._targets:
                         if t in baseClasses:
                             for prefViewer in preferredViewers:
                                 if viewer is prefViewer:
                                     viewers.insert(0, viewer)
+                                    viewerAdded=True
                                     preferedFlag = 1
                                     break
                             else:
                                 if t == clazz:
                                     viewers.insert(preferedFlag, viewer)
+                                    viewerAdded = True
                                 else:
                                     viewers.append(viewer)
+                                    viewerAdded = True
                                 break
+
+                        if viewerAdded:
+                            break
+
         except Exception as e:
             # Catch if there is a missing plugin, we will get Legacy which triggers and Exception
             pass
@@ -521,10 +537,14 @@ class Plugin:
     _homeVar = ''  # Change in subclasses to define the "home" variable
     _pathVars = []
     _supportedVersions = []
-    _name = ""
     _url = ""  # For the plugin
     _condaActivationCmd = None
 
+    def __init__(self):
+        self._path = None
+        self._inDevelMode = None
+        self._name = None
+
     @classmethod
     def _defineVar(cls, varName, defaultValue):
         """ Internal method to define variables trying to get it from the environment first. """
@@ -538,11 +558,12 @@ class Plugin:
     @classmethod
     @abstractmethod
     def getEnviron(cls):
-        """ Setup the environment variables needed to launch programs. """
+        """ Set up the environment variables needed to launch programs. """
         pass
 
     @classmethod
     def getCondaActivationCmd(cls):
+        """ Returns the conda activation command with && at the end if defined otherwise empty"""
         if cls._condaActivationCmd is None:
             condaActivationCmd = pw.Config.CONDA_ACTIVATION_CMD
             if not condaActivationCmd:
@@ -613,10 +634,6 @@ class Plugin:
 
         return ''
 
-    @classmethod
-    def getName(cls):
-        return cls.__module__
-
     @classmethod
     def validateInstallation(cls):
         """
@@ -637,23 +654,32 @@ class Plugin:
             return ["validateInstallation fails: %s" % e]
 
     @classmethod
-    def getPluginDir(cls):
-        return os.path.join(pw.getModuleFolder(cls.getName()))
+    def getUrl(cls, protClass=None):
+        """ Url for the plugin to point users to it"""
+        return cls._url
 
-    @classmethod
-    def getPluginTemplateDir(cls):
-        return os.path.join(cls.getPluginDir(), 'templates')
+    # -------------- Instance methods ----------------
+    def getName(self):
+        if self._name is None:
+            self._name=  self.__class__.__module__
+
+        return self._name
+
+    def getPluginDir(self):
+        return self.getPath()
+
+    def getPluginTemplateDir(self):
+        return os.path.join(self.getPath(), 'templates')
 
 
-    @classmethod
-    def getTemplates(cls):
+    def getTemplates(self):
         """ Get the plugin templates from the templates directory.
             If more than one template is found or passed, a dialog is raised
             to choose one.
         """
         tempList = []
-        pluginName = cls.getName()
-        tDir = cls.getPluginTemplateDir()
+        pluginName = self.getName()
+        tDir = self.getPluginTemplateDir()
         if os.path.exists(tDir):
             for file in glob.glob1(tDir, "*" + SCIPION_JSON_TEMPLATES):
                 t = Template(pluginName, os.path.join(tDir, file))
@@ -661,10 +687,16 @@ class Plugin:
 
         return tempList
 
-    @classmethod
-    def getUrl(cls, protClass=None):
-        """ Url for the plugin to point users to it"""
-        return cls._url
+    def getPath(self):
+        if self._path is None:
+            self._path = sys.modules[self.__class__.__module__].__path__[0]
+
+        return self._path
+    def inDevelMode(self)-> bool:
+        """ Returns true if code is not in python's site-packages folder"""
+        if self._inDevelMode is None:
+            self._inDevelMode = pwutils.getPythonPackagesFolder() not in self.getPath()
+        return self._inDevelMode
 
 
 class PluginInfo:
