@@ -24,12 +24,10 @@
 # *
 # **************************************************************************
 
-
-import os
+import logging
+logger = logging.getLogger(__name__)
 import json
 import datetime as dt
-from collections import OrderedDict
-from configparser import ConfigParser
 
 import pyworkflow.object as pwobj
 from pyworkflow.mapper import SqliteMapper
@@ -148,12 +146,43 @@ class ProjectSettings(pwobj.Object):
     def getNodes(self):
         return self.nodeList
 
+    def cleanUpNodes(self, runsIds, toRemove=True):
+        """ This will clean up all the nodes that do not have a matching run.
+        This is because until now, the nodes here weren't removes when protocols were removed.
+
+        :param runsIds: iterable with protocol's objId to be removed.
+        :param toRemove: Passed is are to be removed. Otherwise, are the ones to keep
+        """
+
+        try:
+            logger.info("Cleaning up unused graphical nodes.")
+
+            nodesToDelete = []
+            for node  in self.getNodes():
+                nodeId = str(node.getId())
+                # if it is not the root node
+                if nodeId != '0':
+
+                    if (nodeId in runsIds) == toRemove:
+                        nodesToDelete.append(node.getId())
+
+            logger.info("Following graphical nodes %s unmatched. Deleting them" % nodesToDelete)
+            for key in nodesToDelete:
+                self.getNodes().removeNode(key)
+                
+        except Exception as e:
+            logger.error("Couldn't clean up graphical nodes.", exc_info=e)
+
     def getNodeById(self, nodeId):
         return self.nodeList.getNode(nodeId)
 
     def addNode(self, nodeId, **kwargs):
         return self.nodeList.addNode(nodeId, **kwargs)
 
+    def removeNode(self, nodeId):
+        """ Removes a graphical node based on its id"""
+        self.nodeList.removeNode(nodeId)
+
     def getLabels(self):
         return self.labelsList
 
@@ -328,6 +357,12 @@ class NodeConfigList(pwobj.List):
         self.append(node)
         return node
 
+    def removeNode(self, nodeId):
+        """ Removes a node with the id = nodeId"""
+        nodeToRemove = self._nodesDict[nodeId]
+        self._nodesDict.pop(nodeId)
+        self.remove(nodeToRemove)
+
     def updateDict(self):
         self._nodesDict.clear()
         for node in self:
@@ -341,12 +376,14 @@ class NodeConfigList(pwobj.List):
 class Label(pwobj.Scalar):
     """ Store Label information """
 
-    def __init__(self, labelId=None, name='', color=None):
+    EMPTY_OLD_NAME = None
+
+    def __init__(self, name='', color=None):
         pwobj.Scalar.__init__(self)
         # Special node id 0 for project node
-        self._values = {'id': labelId,
-                        'name': name,
+        self._values = {'name': name,
                         'color': color}
+        self._oldName = self.EMPTY_OLD_NAME
 
     def _convertValue(self, value):
         """Value should be a str with comma separated values
@@ -354,26 +391,43 @@ class Label(pwobj.Scalar):
         """
         self._values = json.loads(value)
 
+        # Clean unused "id" field
+        if "id" in self._values:
+            self._values.pop("id")
+
     def getObjValue(self):
         self._objValue = json.dumps(self._values)
+        
         return self._objValue
 
     def get(self):
         return self.getObjValue()
 
-    def getId(self):
-        return self._values['id']
 
-    def getName(self):
+    def getName(self)->str:
         return self._values['name']
 
     def setName(self, newName):
+        # For recurrent edit,
+        # we keep the old name only the first time
+        if not self.hasOldName():
+            self._oldName = self._values['name']
+
         self._values['name'] = newName
 
+    def hasOldName(self)->bool:
+        return self._oldName != self.EMPTY_OLD_NAME
+
+    def clearOldName(self):
+        self._oldName = self.EMPTY_OLD_NAME
+
+    def getOldName(self)->str:
+        return self._oldName
+
     def setColor(self, color):
         self._values['color'] = color
 
-    def getColor(self):
+    def getColor(self)->str:
         return self._values.get('color', None)
 
     def __str__(self):
