@@ -2,6 +2,8 @@
 
 import sys
 import os
+import logging
+logging.basicConfig(level="INFO")
 
 from pyworkflow.project import Manager
 import pyworkflow.utils as pwutils
@@ -11,10 +13,9 @@ def usage(error):
     print("""
     ERROR: %s
     
-    Usage: python -m pyworkflow.project.script.fix_links PROJECT SEARCH_DIR
-        PROJECT: provide the project name to fix broken links in the imports.
-        SEARCH_DIR: provide a directory where to look for the files.
-        and fix the links.    
+    Usage: scipion python -m pyworkflow.project.scripts.fix_links PROJECT SEARCH_DIR
+        PROJECT: provide the project name to fix broken links in the imports
+        SEARCH_DIR: provide a directory where to look for the files and fix the links    
     """ % error)
     os._exit(1)
 
